@@ -119,65 +119,134 @@ Pi
 
 
 ###################################################
-### code chunk number 17: Math-group
+### code chunk number 17: pi-fn-Gauss-HB
+###################################################
+piMpfr <- function(prec=256, itermax = 100, verbose=TRUE) {
+    m2 <- mpfr(2, prec) # '2' as mpfr number
+    ## -> all derived numbers are mpfr (with precision 'prec')
+    p <- m2 + sqrt(m2) # 2 + sqrt(2) = 3.414..
+    y <- sqrt(sqrt(m2)) # 2^ {1/4}
+    x <- (y+1/y) / m2
+    it <- 0L
+    repeat {
+	p.old <- p
+	it <- it+1L
+	p <- p * (1+x) / (1+y)
+	if(verbose) cat(sprintf("it=%2d, pi^ = %s, |.-.|/|.|=%e\n",
+				it, formatMpfr(p, min(50, prec/log2(10))), 1-p.old/p))
+	if (abs(p-p.old) <= m2^(-prec))
+	    break
+	if(it > itermax) {
+	    warning("not converged in", it, "iterations") ; break
+	}
+	## else
+	s <- sqrt(x)
+	y <- (y*s + 1/s) / (1+y)
+	x <- (s+1/s)/2
+    }
+    p
+}
+
+piMpfr()# indeed converges  *quadratically* fast
+## with relative error
+relErr <- 1 - piMpfr(256, verbose=FALSE) / Const("pi",260)
+## in bits :
+asNumeric(-log2(abs(relErr)))
+
+
+###################################################
+### code chunk number 18: Math2-def
+###################################################
+getGroupMembers("Math2")
+showMethods("Math2", classes=c("mpfr", "mpfrArray"))
+
+
+###################################################
+### code chunk number 19: round-ex
+###################################################
+i7 <- 1/mpfr(700, 100)
+c(i7, round(i7, digits = 6), signif(i7, digits = 6))
+
+
+###################################################
+### code chunk number 20: roundMpfr-ex
+###################################################
+roundMpfr(i7, precBits = 30)
+roundMpfr(i7, precBits = 15)
+
+
+###################################################
+### code chunk number 21: asNumeric-meth
+###################################################
+showMethods(asNumeric)
+
+
+###################################################
+### code chunk number 22: format-ex
+###################################################
+cbind( sapply(1:7, function(d) format(i7, digits=d)) )
+
+
+###################################################
+### code chunk number 23: Math-group
 ###################################################
 getGroupMembers("Math")
 
 
 ###################################################
-### code chunk number 18: Matrix-ex
+### code chunk number 24: Matrix-ex
 ###################################################
 head(x <- mpfr(0:7, 64)/7) ; mx <-  x
 dim(mx) <- c(4,2)
 
 
 ###################################################
-### code chunk number 19: mpfrArr-ex
+### code chunk number 25: mpfrArr-ex
 ###################################################
 dim(aa <- mpfrArray(1:24, precBits = 80, dim = 2:4))
 
 
 ###################################################
-### code chunk number 20: pr-mpfrArr-fake (eval = FALSE)
+### code chunk number 26: pr-mpfrArr-fake (eval = FALSE)
 ###################################################
 ## aa
 
 
 ###################################################
-### code chunk number 21: pr-mpfrArr-do
+### code chunk number 27: pr-mpfrArr-do
 ###################################################
 capture.and.write(aa, 11, 4)
 
 
 ###################################################
-### code chunk number 22: crossprod
+### code chunk number 28: crossprod
 ###################################################
 mx[ 1:3, ] + c(1,10,100)
 crossprod(mx)
 
 
 ###################################################
-### code chunk number 23: apply-mat
+### code chunk number 29: apply-mat
 ###################################################
 apply(7 * mx, 2, sum)
 
 
 ###################################################
-### code chunk number 24: Ei-curve
+### code chunk number 30: Ei-curve
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 curve(Ei,  0, 5, n=2001);  abline(h=0,v=0, lty=3)
 
 
 ###################################################
-### code chunk number 25: Li2-1
+### code chunk number 31: Li2-1
 ###################################################
 if(mpfrVersion() >= "2.4.0")  ## Li2() is not available in older MPFR versions
   all.equal(Li2(1), Const("pi", 128)^2/6, tol = 1e-30)
 
 
 ###################################################
-### code chunk number 26: Li2-curve
+### code chunk number 32: Li2-curve
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 if(mpfrVersion() >= "2.4.0")
@@ -185,7 +254,7 @@ if(mpfrVersion() >= "2.4.0")
 
 
 ###################################################
-### code chunk number 27: erf-curves
+### code chunk number 33: erf-curves
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 curve(erf, -3,3, col = "red", ylim = c(-1,2))
@@ -195,7 +264,7 @@ legend(-3,1, c("erf(x)", "erfc(x)"), col = c("red","blue"), lty=1)
 
 
 ###################################################
-### code chunk number 28: integrateR-dnorm
+### code chunk number 34: integrateR-dnorm
 ###################################################
 integrateR(dnorm,0,2000)
 integrateR(dnorm,0,2000, rel.tol=1e-15)
@@ -203,13 +272,13 @@ integrateR(dnorm,0,2000, rel.tol=1e-15, verbose=TRUE)
 
 
 ###################################################
-### code chunk number 29: integ-exp-double
+### code chunk number 35: integ-exp-double
 ###################################################
 (Ie.d <- integrateR(exp,            0     , 1, rel.tol=1e-15, verbose=TRUE))
 
 
 ###################################################
-### code chunk number 30: integ-exp-mpfr
+### code chunk number 36: integ-exp-mpfr
 ###################################################
 (Ie.m <- integrateR(exp, mpfr(0,200), 1, rel.tol=1e-25, verbose=TRUE))
 (I.true <- exp(mpfr(1, 200)) - 1)
@@ -219,7 +288,7 @@ as.numeric(c(I.true - Ie.d$value,
 
 
 ###################################################
-### code chunk number 31: integ-poly-double
+### code chunk number 37: integ-poly-double
 ###################################################
 if(require("polynom")) {
     x <- polynomial(0:1)
