@@ -419,7 +419,7 @@ SEXP R_mpfr_prec_range(SEXP ind) {
     UNPROTECT(1);				\
     return val
 
-SEXP const_asMpfr(SEXP I, SEXP prec)
+SEXP const_asMpfr(SEXP I, SEXP prec, SEXP rnd_mode)
 {
     SEXP val;
     mpfr_t r;
@@ -428,10 +428,10 @@ SEXP const_asMpfr(SEXP I, SEXP prec)
     mpfr_init2(r, i_p);
 
     switch(asInteger(I)) {
-    case 1: mpfr_const_pi     (r, MPFR_RNDN); break;
-    case 2: mpfr_const_euler  (r, MPFR_RNDN); break;
-    case 3: mpfr_const_catalan(r, MPFR_RNDN); break;
-    case 4: mpfr_const_log2   (r, MPFR_RNDN); break;
+    case 1: mpfr_const_pi     (r, R_rnd2MP(rnd_mode)); break;
+    case 2: mpfr_const_euler  (r, R_rnd2MP(rnd_mode)); break;
+    case 3: mpfr_const_catalan(r, R_rnd2MP(rnd_mode)); break;
+    case 4: mpfr_const_log2   (r, R_rnd2MP(rnd_mode)); break;
     default:
 	error("invalid integer code {const_asMpfr()}"); /* -Wall */
     }
@@ -465,10 +465,42 @@ R_MPFR_Logic_Function(R_mpfr_is_integer,  mpfr_integer_p)
 R_MPFR_Logic_Function(R_mpfr_is_na,       mpfr_nan_p)
 R_MPFR_Logic_Function(R_mpfr_is_zero,     mpfr_zero_p)
 
-SEXP R_mpfr_fac (SEXP n_, SEXP prec)
+#define R_MPFRarray_Logic_Function(_FNAME, _MPFR_NAME)			\
+SEXP _FNAME(SEXP x) {							\
+    SEXP D = PROTECT(GET_SLOT(x, Rmpfr_Data_Sym)),/* R list() */	\
+       dim = PROTECT(GET_SLOT(x, Rmpfr_Dim_Sym)),			\
+        dn = PROTECT(GET_SLOT(x, Rmpfr_Dimnames_Sym));			\
+    int n = length(D), i;						\
+    SEXP val = PROTECT(allocVector(LGLSXP, n));				\
+    int *r = LOGICAL(val);						\
+    mpfr_t r_i;								\
+    mpfr_init(r_i);							\
+									\
+    for(i=0; i < n; i++) {						\
+	R_asMPFR(VECTOR_ELT(D, i), r_i);				\
+	r[i] = _MPFR_NAME (r_i);					\
+    }									\
+									\
+    mpfr_clear (r_i);							\
+    mpfr_free_cache();							\
+    setAttrib(val, R_DimSymbol,      duplicate(dim));			\
+    setAttrib(val, R_DimNamesSymbol, duplicate(dn));			\
+    UNPROTECT(4);							\
+    return val;								\
+}
+
+R_MPFRarray_Logic_Function(R_mpfr_is_finite_A,   mpfr_number_p)
+R_MPFRarray_Logic_Function(R_mpfr_is_infinite_A, mpfr_inf_p)
+R_MPFRarray_Logic_Function(R_mpfr_is_integer_A,  mpfr_integer_p)
+R_MPFRarray_Logic_Function(R_mpfr_is_na_A,       mpfr_nan_p)
+R_MPFRarray_Logic_Function(R_mpfr_is_zero_A,     mpfr_zero_p)
+
+
+SEXP R_mpfr_fac (SEXP n_, SEXP prec, SEXP rnd_mode)
 {
     int n = length(n_), i, *nn;
     SEXP n_t, val = PROTECT(allocVector(VECSXP, n)); int nprot = 1;
+    mpfr_rnd_t rnd = R_rnd2MP(rnd_mode);
     mpfr_t r_i;
     if(TYPEOF(n_) != INTSXP) {
 	PROTECT(n_t = coerceVector(n_, INTSXP)); nprot++;/* or bail out*/
@@ -482,7 +514,7 @@ SEXP R_mpfr_fac (SEXP n_, SEXP prec)
     for(i=0; i < n; i++) {
 	// never happens when called from R:
 	if(nn[i] < 0) error("R_mpfr_fac(%d): negative n.", nn[i]);
-	mpfr_fac_ui(r_i, nn[i], MPFR_RNDN);
+	mpfr_fac_ui(r_i, nn[i], rnd);
 	SET_VECTOR_ELT(val, i, MPFR_as_R(r_i));
     }
 
@@ -492,50 +524,12 @@ SEXP R_mpfr_fac (SEXP n_, SEXP prec)
     return val;
 }
 
-#ifdef __NOT_ANY_MORE__
-//       ------------ as we deal with these "as if Math() group"
-// via Math_mpfr() in ./Ops.c
-
-#define R_MPFR_1_Numeric_Function(_FNAME, _MPFR_NAME)			\
-SEXP _FNAME(SEXP x) {							\
-    SEXP D = PROTECT(GET_SLOT(x, Rmpfr_Data_Sym));/* an R list() */	\
-    int n = length(D), i;						\
-    SEXP val = PROTECT(allocVector(VECSXP, n));				\
-    mpfr_t r_i;								\
-    mpfr_init(r_i);							\
-									\
-    for(i=0; i < n; i++) {						\
-	R_asMPFR(VECTOR_ELT(D, i), r_i);				\
-	_MPFR_NAME(r_i, r_i, MPFR_RNDN);					\
-	SET_VECTOR_ELT(val, i, MPFR_as_R(r_i));				\
-    }									\
-									\
-    mpfr_clear (r_i);							\
-    mpfr_free_cache();							\
-    UNPROTECT(2);							\
-    return val;								\
-}
-
-R_MPFR_1_Numeric_Function(R_mpfr_erf, mpfr_erf)
-R_MPFR_1_Numeric_Function(R_mpfr_erfc, mpfr_erfc)
-R_MPFR_1_Numeric_Function(R_mpfr_zeta, mpfr_zeta)
-
-R_MPFR_1_Numeric_Function(R_mpfr_eint, mpfr_eint)
-R_MPFR_1_Numeric_Function(R_mpfr_j0, mpfr_j0)
-R_MPFR_1_Numeric_Function(R_mpfr_j1, mpfr_j1)
-R_MPFR_1_Numeric_Function(R_mpfr_y0, mpfr_y0)
-R_MPFR_1_Numeric_Function(R_mpfr_y1, mpfr_y1)
-
-R_MPFR_1_Numeric_Function(R_mpfr_ai, mpfr_ai)
-
-#endif
-/* __NOT_ANY_MORE__ */
-
 
 #define R_MPFR_2_Numeric_Function(_FNAME, _MPFR_NAME)	\
-SEXP _FNAME(SEXP x, SEXP y) {				\
+SEXP _FNAME(SEXP x, SEXP y, SEXP rnd_mode) {		\
     SEXP xD = PROTECT(GET_SLOT(x, Rmpfr_Data_Sym));	\
     SEXP yD = PROTECT(GET_SLOT(y, Rmpfr_Data_Sym));	\
+    mpfr_rnd_t rnd = R_rnd2MP(rnd_mode);		\
     int nx = length(xD), ny = length(yD), i,		\
 	n = (nx == 0 || ny == 0) ? 0 : imax2(nx, ny);	\
     SEXP val = PROTECT(allocVector(VECSXP, n));		\
@@ -546,7 +540,7 @@ SEXP _FNAME(SEXP x, SEXP y) {				\
     for(i=0; i < n; i++) {				\
 	R_asMPFR(VECTOR_ELT(xD, i % nx), x_i);		\
 	R_asMPFR(VECTOR_ELT(yD, i % ny), y_i);		\
-	_MPFR_NAME(R, x_i, y_i, MPFR_RNDN);		\
+	_MPFR_NAME(R, x_i, y_i, rnd);			\
 	SET_VECTOR_ELT(val, i, MPFR_as_R(R));		\
     }							\
 							\
@@ -564,8 +558,9 @@ R_MPFR_2_Numeric_Function(R_mpfr_lbeta, my_mpfr_lbeta)
 
 
 #define R_MPFR_2_Num_Long_Function(_FNAME, _MPFR_NAME)			\
-SEXP _FNAME(SEXP x, SEXP y) {						\
+SEXP _FNAME(SEXP x, SEXP y, SEXP rnd_mode) {				\
     SEXP xD, yt, val;							\
+    mpfr_rnd_t rnd = R_rnd2MP(rnd_mode);				\
     int *yy, n, nx, ny = length(y), i, nprot = 0;			\
     mpfr_t x_i;								\
 									\
@@ -583,7 +578,7 @@ SEXP _FNAME(SEXP x, SEXP y) {						\
 									\
     for(i=0; i < n; i++) {						\
 	R_asMPFR(VECTOR_ELT(xD, i % nx), x_i);				\
-	_MPFR_NAME(x_i, (long) yy[i % ny], x_i, MPFR_RNDN);		\
+	_MPFR_NAME(x_i, (long) yy[i % ny], x_i, rnd);			\
 	SET_VECTOR_ELT(val, i, MPFR_as_R(x_i));				\
     }									\
 									\
